summaryrefslogtreecommitdiffstats
path: root/kresources/exchange/resourceexchange.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/exchange/resourceexchange.cpp')
-rw-r--r--kresources/exchange/resourceexchange.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kresources/exchange/resourceexchange.cpp b/kresources/exchange/resourceexchange.cpp
index de9158755..b58a750f2 100644
--- a/kresources/exchange/resourceexchange.cpp
+++ b/kresources/exchange/resourceexchange.cpp
@@ -233,7 +233,7 @@ void ResourceExchange::slotMonitorNotify( const TQValueList<long>& IDs, const TQ
* 3. Event modified that we have in cache
* 4. Something else happened that isn't relevant to us
* Update cache, then notify whoever's watching us
* We may be able to tqfind (1) and (3) by looking at the
* DAV:getlastmodified property
* (2) is trickier: we might have to resort to checking
* all uids in the cache
@@ -298,7 +298,7 @@ void ResourceExchange::changeIncidence( Incidence *incidence )
kdDebug() << "ResourceExchange::changeIncidence(): "
<< incidence->summary() << endl;
- if ( mChangedIncidences.tqfind( incidence ) == mChangedIncidences.end() ) {
+ if ( mChangedIncidences.find( incidence ) == mChangedIncidences.end() ) {
mChangedIncidences.append( incidence );
}
}
@@ -481,7 +481,7 @@ Event::List ResourceExchange::rawEventsForDate( const TQDate &qd,
// kdDebug() << "Now is " << now.toString() << endl;
// kdDebug() << "mDates: " << mDates << endl;
TQDate start = TQDate( qd.year(), qd.month(), 1 ); // First day of month
- if ( mDates && ( !mDates->tqcontains( start ) ||
+ if ( mDates && ( !mDates->contains( start ) ||
(*mCacheDates)[start].secsTo( now ) > mCachedSeconds ) ) {
TQDate end = start.addMonths( 1 ).addDays( -1 ); // Last day of month
// Get events that occur in this period from the cache
@@ -505,7 +505,7 @@ Event::List ResourceExchange::rawEventsForDate( const TQDate &qd,
// are really new.
Event::List eventsAfter = mCache->rawEvents();
for ( it = eventsAfter.begin(); it != eventsAfter.end(); ++it ) {
- if ( eventsBefore.tqfind( *it ) == eventsBefore.end() ) {
+ if ( eventsBefore.find( *it ) == eventsBefore.end() ) {
// it's a new event downloaded by downloadSynchronous -> install observer
(*it)->registerObserver( this );
}
@@ -233,7 +233,7 @@ void ResourceExchange::slotMonitorNotify( const TQValueList<long>& IDs, const TQ
* 4. Something else happened that isn't relevant to us
* Update cache, then notify whoever's watching us
- * We may be able to tqfind (1) and (3) by looking at the
+ * We may be able to find (1) and (3) by looking at the
* DAV:getlastmodified property
* (2) is trickier: we might have to resort to checking